%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: 0readme.m,v 1.1 1998/06/10 02:42:07 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Purpose:
%
%    The FEMBIF package implements piecewise linear simplicial finite
%    elements, a posteriori error estimation, adaptive mesh refinement
%    (quadrasection and bisection), continuation methods, and global
%    inexact-newton methods for nonlinear elliptic equations on arbitrary
%    polyhedral domains in 2D.
%
%    This package solves the following general second order
%    nonlinear elliptic equation posed in a weak formulation:
%
%       Find [u+g] in H^1_0(\Omega) such that 
%
%                <F(u),v> = 0, for all v in H^1_0(\Omega),
%
%    where <F(u),v> is the nonlinear weak form generated (by appropriate
%    integration by parts) from a second-order, divergence-form, nonlinear 
%    elliptic equation in a polyhedral domain in R^2.
%
%    Given the general nature of the above formulation, quite general
%    boundary conditions can be employed.  The user must specify the
%    dirichlet function g, the domain \Omega, the nonlinear form <F(u),v>,
%    and also a linearization form <DF(u),v>.
%
% Package files:
%
%   % documentation files
%   file 0readme.m     # THIS FILE -- description of the package
%   file 0license.m    # the GNU license which governs package distribution
%
%   % primary controlling routines
%   file go.m          # main fembif driver program
%   file assem.m       # assemble the discrete system
%   file newton.m      # solve the discrete system with newton's method
%   file mastr.m       # get master element information
%   file mesh.m        # define the mesh by modifing a standard "MCF" mesh file
%   file mcf.m         # a standard "MCF" mesh file
%
%   % high-level mesh marking and refinement routines
%   file mark.m        # mark elements for refinement (e.g., error estimation)
%   file markclr.m     # clear marked elements
%   file refin.m       # refine a set of marked elements to conformity
%   file refinbis.m    # one pass through elements, bisecting marked ones
%   file refinqud.m    # one pass through elements, quadrasecting marked ones
%
%   % low-level mesh manipulation routines
%   file sinring.m     # is simplex in the simplex ring
%   file addering.m    # add edge to the simplex ring
%   file addsring.m    # add simplex to the simplex ring
%   file bldsring.m    # build all of the simplex rings
%   file chkmesh.m     # extensive consistency/conformity check of entire mesh
%   file delsring.m    # delete a simplex from all of its rings
%   file getedge.m     # get the edge (if it exists) connecting two vertices
%   file getnabor.m    # get the simplex nabor (if it exists) sharing a face
%   file kilring.m     # destroy all of the simplex ring structures
%   file longedge.m    # determine the longest edge of a simplex
%
%   % user-defined problem
%   file fu_v.m        # nonlinear weak form defining the pde
%   file dfu_wv.m      # linearization bilinear form for the pde
%   file u_d.m         # dirichlet boundary function
%   file u_t.m         # optional analytical true solution for testing purposes
%
%   % misc untilities and plotting tools
%   file assert.m      # slick assertion macro for debugging
%   file mypaus.m      # pause until the return key is pressed
%   file draw.m        # draw a mesh of vertices and simplices
%   file drawf.m       # draw a function over a mesh of vertices and simplices
%   file u.m           # move the plot up
%   file d.m           # move the plot down
%   file r.m           # move the plot right
%   file l.m           # move the plot left
%
% Author:   Michael Holst 060898
