function [VERT_F,SIMP_F] = bldsring(VERT,SIMP);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: bldsring.m,v 1.1 1998/06/10 02:42:07 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [VERT_F,SIMP_F] = bldsring(VERT,SIMP);
%
% Purpose:
%
%    Builds all of the simplex rings associated with all the vertices 
%    and all simplices in the mesh.
%
% Input:
%
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%
% Output:
%
%    VERT_F = list of vertices in the mesh with the new ring info
%    SIMP_F = list of simplices in the mesh with the new ring info
%
% Author:   Michael Holst 060898
%

%%% recover array dimensions

   [N,eight]     = size(VERT);
   [L,seventeen] = size(SIMP);

%%% add each simplex one at a time to the associated rings

   [VERT,SIMP] = kilring(VERT,SIMP);
   for which=1:L
       [VERT,SIMP] = addsring(VERT,SIMP,which);
   end

%%% return the results

   VERT_F = VERT;
   SIMP_F = SIMP;

