function [VERT_F,SIMP_F] = delsring(VERT,SIMP,which);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: delsring.m,v 1.1 1998/06/10 02:42:07 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [VERT_F,SIMP_F] = delsring(VERT,SIMP,which);
%
% Purpose:
%
%    Delete a simplex from the simplex rings associated with each vertex.
%
% Input:
%
%    which  = the simplex number to delete from rings
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%    
% Output:
%
%    VERT_F = list of vertices in the mesh with the new ring info
%    SIMP_F = list of simplices in the mesh with the new ring info
%
% Author:   Michael Holst 060898
%

%%% recover array dimensions

   T=3;

%%% delete the "which" simplex from the rings

   for i=1:T
      vn    = SIMP( which, i    );  %%% the current vertex number
      vr    = SIMP( which, i+13 );  %%% the next simplex in the ring
      nextS = VERT( vn, 7 );        %%% first simp in ring of current vertex
      loop = 0;
      while ( nextS ~= 0 )
         loop=loop+1;
         if ( nextS == which )
            if (loop == 1)
                VERT( vn, 7 ) = vr;
            else
                SIMP( prevS, prevI+13 ) = vr;
            end
            SIMP(which,i+13) = 0;
            nextS = 0;
         else
            ii = -1;
            for j=1:T
               if ( SIMP(nextS,j) == vn ) ii = j; end
            end
            prevI = ii;
            prevS = nextS;
            nextS = SIMP( prevS, prevI+13 );
            assert( (ii>0), 'delsring 1' );
         end
      end
   end

%%% return the results

   VERT_F = VERT;
   SIMP_F = SIMP;

