function [edg] = getedge(VERT,EDGE,g1,g2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: getedge.m,v 1.1 1998/06/10 02:42:08 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [edg] = getedge(VERT,EDGE,g1,g2);
%
% Purpose:
%
%    Find the edge (if it exists) connecting g1-g2
%
% Input:
%
%    g1     = first vertex of the edge
%    g2     = second vertex of the edge
%    VERT   = <see "mesh.m" for description of the datastructure>
%    EDGE   = <see "mesh.m" for description of the datastructure>
%    
% Output:
%
%    edg    = the number of the edge (or zero if not found)
%
% Author:   Michael Holst 060898
%

%%% recover array dimensions

   T=3;

%%% fine the edge using the rings

   %%% get the edge rings for the first vertex
   ring1 = [];
   nextE = VERT(g1,8);
   if (nextE ~= 0)
      ring1 = [ ring1 ; nextE ];
   end
   while ( nextE ~= 0 )
      locv = EDGE(nextE,1:2);
      lfind = 0;
      if (locv(1)==g1) lfind = 1; end;
      if (locv(2)==g1) lfind = 2; end;
      assert( (lfind>0), 'getedge 1' );
      nextE = EDGE(nextE,lfind+6);
      if (nextE ~= 0)
         ring1 = [ ring1 ; nextE ];
      end
   end

   %%% get the edge rings for the first vertex
   ring2 = [];
   nextE = VERT(g2,8);
   if (nextE ~= 0)
      ring2 = [ ring2 ; nextE ];
   end
   while ( nextE ~= 0 )
      locv = EDGE(nextE,1:2);
      lfind = 0;
      if (locv(1)==g2) lfind = 1; end;
      if (locv(2)==g2) lfind = 2; end;
      assert( (lfind>0), 'getedge 2' );
      nextE = EDGE(nextE,lfind+6);
      if (nextE ~= 0)
         ring2 = [ ring2 ; nextE ];
      end
   end

   %%% see if there is a common edge
   [n1,one] = size(ring1);
   [n2,one] = size(ring2);
   eg = 0;
   for i1=1:n1
      for i2=1:n2
         if (ring1(i1) == ring2(i2))
            assert( (eg==0), 'getedge 3' );
            eg = ring1(i1);
         end
      end
   end

%%% return the results

   edg = eg;

