function [nab] = getnabor(VERT,SIMP,me,v1,v2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: getnabor.m,v 1.1 1998/06/10 02:42:08 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [nab] = getnabor(VERT,SIMP,me,v1,v2);
%
% Purpose:
%
%    Find the nabor simplex (if it exists) sharing edge v1-v2
%
% Input:
%
%    v1     = first vertex of the edge
%    v2     = second vertex of the edge
%    me     = the particular simplex we are working with
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%    
% Output:
%
%    nab    = the number of the nabor simplex (or zero if not found)
%
% Author:   Michael Holst 060898
%

%%% recover array dimensions

   T=3;

%%% fine the nabor simplex using the rings

   g1 = SIMP(me,v1);
   g2 = SIMP(me,v2);
   
   %%% get the simplex rings for the first vertex
   ring1 = [];
   nextS = VERT(g1,7);
   if ((nextS ~= me) & (nextS ~= 0))
      ring1 = [ ring1 ; nextS ];
   end
   while ( nextS ~= 0 )
      locv = SIMP(nextS,1:3);
      lfind = 0;
      if (locv(1)==g1) lfind = 1; end;
      if (locv(2)==g1) lfind = 2; end;
      if (locv(3)==g1) lfind = 3; end;
      assert( (lfind>0), 'getnabor 1' );
      nextS = SIMP(nextS,lfind+13);
      if ((nextS ~= me) & (nextS ~= 0))
         ring1 = [ ring1 ; nextS ];
      end
   end

   %%% get the simplex rings for the first vertex
   ring2 = [];
   nextS = VERT(g2,7);
   if ((nextS ~= me) & (nextS ~= 0))
      ring2 = [ ring2 ; nextS ];
   end
   while ( nextS ~= 0 )
      locv = SIMP(nextS,1:3);
      lfind = 0;
      if (locv(1)==g2) lfind = 1; end;
      if (locv(2)==g2) lfind = 2; end;
      if (locv(3)==g2) lfind = 3; end;
      assert( (lfind>0), 'getnabor 2' );
      nextS = SIMP(nextS,lfind+13);
      if ((nextS ~= me) & (nextS ~= 0))
         ring2 = [ ring2 ; nextS ];
      end
   end

   %%% see if there is a common simplex
   [n1,one] = size(ring1);
   [n2,one] = size(ring2);
   nb = 0;
   for i1=1:n1
      for i2=1:n2
         if (ring1(i1) == ring2(i2))
            assert( (nb==0), 'getnabor 3' );
            nb = ring1(i1);
         end
      end
   end

%%% return the results

   nab = nb;

