%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: go.m,v 1.1 1998/06/10 02:42:08 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    None (script)
%
% Purpose:
%
%    Driver script for FEMBIF package.
%
% Author:   Michael Holst 060898
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% some i/o

   clc; clf; 
   fprintf('\n');
   fprintf('-------------------------------------------------------------\n');
   fprintf('FEMBIF version 1.0, Copyright (C) 1998 Michael Holst\n');
   fprintf('This is free software, and you are welcome to redistribute it\n');
   fprintf('under certain conditions; type "help 0license" for details.\n');
   fprintf('Note that FEMBIF comes with ABSOLUTELY NO WARRANTY.\n');
   fprintf('\n');
   fprintf('For FEMBIF documentation:  In MATLAB, type "help filename".\n');
   fprintf('-------------------------------------------------------------\n');
   fprintf('\n');

   fprintf('MAIN: STARTING: Finite Element Bifurcation Code\n');

%%% controlling parameters

   levels      = 23; %%% num of refinements plus one
   refkey      = 0;  %%% refinement type (0=bisection,1=quadrasection)
   estkey      = 1;  %%% estimator (0=mark all,1=geometric,2=a posteriori)
   solkey      = 0;  %%% solve key (0=no, 1=yes)
   chkkey      = 0;  %%% conformity check the mesh (0=no,1=yes--check is slow)

   iplotMesh   = 1;  %%% plot of mesh (0=none,1=mesh)
   igraphA     = 1;  %%% graph of matrix (0=none,1=graph)
   ispyA       = 1;  %%% spy of matrix (0=none,1=spy)
   iplotSol    = 1;  %%% plot of solution (0=none,1=soln)
   igenPS      = 0;  %%% generate postscript (0=no,1=yes)

%%% construct operators for the nested sequence of spaces

   for level = 1 : levels
      fprintf('MAIN: -------\n');
      fprintf('MAIN: LEVEL %g\n',level);
      fprintf('MAIN: -------\n');

      if (level == 1)
         %%% create the initial coarse mesh
         fprintf('MAIN: defining the mesh..');
         t0 = clock;
         [VERT,SIMP]   = mesh(0);
         the_time = etime(clock,t0);
         [N,eight]     = size(VERT);
         [L,seventeen] = size(SIMP);
         fprintf('..done.  [N=%g,L=%g]  [time=%g]\n',N,L,the_time);
      else
         %%% error estimate and the mark mesh (some uniform refinements first)
         fprintf('MAIN: marking  the mesh..');
         t0 = clock;
         [SIMP,QUE]    = mark(VERT,SIMP,estkey);
         the_time = etime(clock,t0);
         [N,eight]     = size(VERT);
         [L,seventeen] = size(SIMP);
         fprintf('..done.  [N=%g,L=%g]  [time=%g]\n',N,L,the_time);

         %%% adaptively refine the mesh based on the marking
         fprintf('MAIN: refining the mesh..');
         t0 = clock;
         [VERT,SIMP]   = refin(VERT,SIMP,QUE,refkey);
         the_time = etime(clock,t0);
         [N,eight]     = size(VERT);
         [L,seventeen] = size(SIMP);
         fprintf('..done.  [N=%g,L=%g]  [time=%g]\n',N,L,the_time);
      end;

      %%% check the mesh for "correctness"
      if (chkkey > 0)
         chkmesh(VERT,SIMP);
      end

      %%% plot the mesh
      if (iplotMesh > 0)
         fprintf('MAIN: plotting the mesh..');
         draw(VERT,SIMP);
         if (igenPS > 0)
            print -dps mesh.ps
         end
         fprintf('..done.  [N=%g,L=%g]\n',N,L);
         mypaus;
      end;

      %%% solve discrete system?
      if (solkey > 0)

          %%% solve discrete system
          fprintf('MAIN: nonlinear solve starting.  [N=%g,L=%g]\n',N,L);
          t0 = clock;
          [U,Ug,A,F]=newton(VERT,SIMP);
          the_time = etime(clock,t0);
          fprintf('MAIN: nonlinear solve finished.  [time=%g]\n',the_time);

          %%% discretization error test
          U_t = zeros(N,1);
          U_t(1:N,1) = u_t(VERT(1:N,1), VERT(1:N,2));
          error = norm(U_t - (U+Ug)) / norm(U_t);
          fprintf('MAIN: discretization error is = %g\n',error); 

          %%% graph the matrix
          if (igraphA > 0)
             fprintf('MAIN: graphing matrix..');
             gplot(A,VERT,'b');
             if (igenPS > 0)
                print -dps graph.ps
             end
             fprintf('..done.  [N=%g,L=%g]\n',N,L);
             mypaus;
          end;

          %%% show matrix structure 
          if (ispyA > 0)
             fprintf('MAIN: showing nonzero structure..');
             clf; hold off; 
             spy(A);
             if (igenPS > 0)
                print -dps spy.ps
             end
             fprintf('..done.  [N=%g,L=%g]\n',N,L);
             mypaus; 
          end;

          %%% plot the solution
          if (iplotSol > 0)
             fprintf('MAIN: plotting FEM solution..');
             drawf(VERT,SIMP,(U+Ug));
             view(30,30);
             if (igenPS > 0)
                print -dps sol.ps
             end
             fprintf('..done.  [N=%g,L=%g]\n',N,L);
             mypaus; 
          end;

       end; %%% solve discrete system

   end; %%% solve-estimate-refine loop

