function [SIMP_F,QUE_F] = mark(VERT,SIMP,estkey);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: mark.m,v 1.1 1998/06/10 02:42:08 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [SIMP_F,QUE_F] = mark(SIMP);
%
% Purpose:
%
%    Mark some simplices for refinement.
%
% Input:
%
%    estkey = which marker to use
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%
% Output:
%
%    SIMP_F = marked set of simplices
%    QUE_F  = list of the simplex numbers that were marked for refinement
%
% Author:   Michael Holst 060898
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% recover array dimensions

   [L,seventeen] = size(SIMP);
   T=3;

%%% we always place the elements into the first q

   whichq = 1;

%%% the estimate loop

   if (estkey==2)
      fprintf('\n');
      fprintf('\n');
      fprintf('mark: YOU NEED TO DEFINE THE ERROR ESTIMATOR IN <mark.m>\n');
      fprintf('\n');
   end

   QUE = [];
   rad = .25;
   for l=1:L
      markit = 0;

      if (estkey==0)
         markit = 1;
      end;

      if (estkey==1)
         d1 = norm( VERT( SIMP(l,1), 1:3 ) );
         d2 = norm( VERT( SIMP(l,2), 1:3 ) );
         d3 = norm( VERT( SIMP(l,3), 1:3 ) );
         if ( ~ ((d1 < rad) & (d2 < rad) & (d3 < rad)) ...
            & ~ ((d1 > rad) & (d2 > rad) & (d3 > rad)) )
            markit = 1;
         end
      end

      if (estkey==2)
         %%% YOUR ERROR ESTIMATOR GOES HERE
      end

      if (markit > 0)
         SIMP(l,whichq+11) = 1;
         QUE = [ QUE ; l ];
      end

   end

%%% return the marked simplices

   SIMP_F = SIMP;
   QUE_F  = QUE;

