function [U,Ug,A,F]=newton(VERT, SIMP);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: newton.m,v 1.1 1998/06/10 02:42:09 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [U,Ug,A,F]=newton(VERT, SIMP);
%
% Purpose:
%
%    Discretize and solve the nonlinear pde with a newton iteration.
%
% Input:
%
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%
% Output:
%
%    U    = solution to nonlinear problem
%    Ug   = essential/dirichlet boundary function
%    A    = last jacobian matrix
%    F    = last nonlinear residual vector
%
% Author:   Michael Holst 060898
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   %%% sizes of things
   [N,eight]     = size(VERT);
   [L,seventeen] = size(SIMP);

   %%% initial FEM solution
   U=zeros(N,1);

   %%% initial essential/dirichlet function
   Ug=zeros(N,1);
   Ug(1:N,1) = u_d( VERT(1:N,1), VERT(1:N,2) ) ...
             .* ( VERT(1:N,6) == ones(N,1) );

   %%% parameters
   parm = zeros(10,1);

   %%% newton iteration
   itmax = 30;
   errtol = 1.0e-5;
   iter = 0;
   done = 0;
   while ((done == 0) & (iter < itmax))
      iter = iter + 1;

      %%% assemble jacobian system
      assKey = 2;
      parm(1) = 1;
      [A,F]=assem(assKey, parm, U, Ug, VERT, SIMP);

      %%% initial residual
      if (iter == 1)
         normF = norm(F,2);
         fprintf('NEWTON: iter = %g, ||F(u)|| = %g\n', 0, normF);
      end

      %%% solve jacobian system
      E = A \ F;

      %%% correct the solution
      U = U + E;

      %%% nonlinear residual
      assKey = 3;
      parm(1) = 1;
      [A,F]=assem(assKey, parm, U, Ug, VERT, SIMP);

      %%% solution quality
      normF = norm(F,2);
      fprintf('NEWTON: iter = %g, ||F(u)|| = %g\n', iter, normF);
      if (normF < errtol)
         done = 1;
      end;
   end

