function [VERT_F,SIMP_F] = refin(VERT,SIMP,QUE,refkey);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: refin.m,v 1.1 1998/06/10 02:42:09 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [VERT_F,SIMP_F] = refin(VERT,SIMP,QUE,refkey);
%
% Purpose:
%
%    Refine the finite element mesh and produce a linear 
%    prolongation operator which relates functions on the two meshes.
%    We perform a conformity loop after the initial refinement loop,
%    and continue until a conforming mesh is obtained.
%
% Input:
%
%    refkey = which refinement stategy to use
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%    QUE    = list of marked simplices to be refined
% 
% Output:
%    
%    VERT_F = list of vertices in the refined mesh
%    SIMP_F = conformally refined set of simplices
%
% Author:   Michael Holst 060898
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   EDGE = [];
   [VERT,SIMP] = bldsring(VERT,SIMP);

   %%% while we have some guys to refine, do it
   [P,one] = size(QUE);
   whichq = 1;
   iter=0;
   while (P > 0)
      iter=iter+1;
      if ((iter==1) & (refkey==1))
         [VERT,SIMP,EDGE,QUE] = refinqud(VERT,SIMP,EDGE,QUE,whichq);
      else
         [VERT,SIMP,EDGE,QUE] = refinbis(VERT,SIMP,EDGE,QUE,whichq);
      end
      [P,one] = size(QUE);
      if (whichq == 1)
          whichq = 2;
      else
          whichq = 1;
      end
   end

   EDGE = [];
   [VERT,SIMP] = kilring(VERT,SIMP);

%%% return the results

   VERT_F = VERT;
   SIMP_F = SIMP;

