function [value] = sinring(VERT,SIMP,me,gv);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1998  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%
%% rcsid="$Id: sinring.m,v 1.1 1998/06/10 02:42:09 mholst Exp $"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [value] = sinring(VERT,SIMP,me,gv);
%
% Purpose:
%
%    Check to see if a simplex is already on a simplex ring.
%
% Input:
%
%    gv     = vertex holding the ring
%    me     = the particular simplex we are working with
%    VERT   = <see "mesh.m" for description of the datastructure>
%    SIMP   = <see "mesh.m" for description of the datastructure>
%    
% Output:
%
%    value  = 1 if in ring, 0 if not in ring
%
% Author:   Michael Holst 060898
%

%%% recover array dimensions

   T=3;

%%% fine the nabor simplex using the rings

   %%% go through the simplex ring
   found = 0;
   nextS = VERT(gv,7);
   if (nextS == me) 
      found = 1;
   end
   while ((nextS ~= 0) & (~found))
      locv = SIMP(nextS,1:3);
      lfind = 0;
      if (locv(1)==gv) lfind = 1; end;
      if (locv(2)==gv) lfind = 2; end;
      if (locv(3)==gv) lfind = 3; end;
      assert( (lfind>0), 'sinring 1' );
      nextS = SIMP(nextS,lfind+13);
      if (nextS == me) 
         found=1;
      end
   end

%%% return the result

   value = found;

